pub enum InputFormat {
Show 17 variants
Text,
Pdf,
Excel,
LegacyExcel,
Word,
LegacyWord,
Presentation,
LegacyPresentation,
OpenDocument,
Archive,
Html,
Image,
Email,
Json,
Csv,
Xml,
LegacyEmail,
}Expand description
File formats Dongler can identify from a path.
File formats are modelled explicitly so loaders and engines can be added
without changing the public format names returned by detect_format.
Variants
Text
Excel
LegacyExcel
Word
LegacyWord
Presentation
LegacyPresentation
OpenDocument
Archive
Html
Image
Json
Csv
Xml
LegacyEmail
Implementations
Sourceimpl InputFormat
impl InputFormat
pub fn detect_path(path: impl AsRef<Path>) -> Result<Self>
pub fn as_str(self) -> &'static str
pub fn extraction_status(self) -> ExtractionStatus